package cn.com.infosec.jce.provider;

import cn.com.infosec.crypto.CipherParameters;
import cn.com.infosec.crypto.PBEParametersGenerator;
import cn.com.infosec.crypto.digests.MD2Digest;
import cn.com.infosec.crypto.digests.MD5Digest;
import cn.com.infosec.crypto.digests.RIPEMD160Digest;
import cn.com.infosec.crypto.digests.SHA1Digest;
import cn.com.infosec.crypto.digests.SHA256Digest;
import cn.com.infosec.crypto.digests.TigerDigest;
import cn.com.infosec.crypto.generators.OpenSSLPBEParametersGenerator;
import cn.com.infosec.crypto.generators.PKCS12ParametersGenerator;
import cn.com.infosec.crypto.generators.PKCS5S1ParametersGenerator;
import cn.com.infosec.crypto.generators.PKCS5S2ParametersGenerator;
import cn.com.infosec.crypto.params.DESParameters;
import cn.com.infosec.crypto.params.KeyParameter;
import cn.com.infosec.crypto.params.ParametersWithIV;
import java.security.spec.AlgorithmParameterSpec;
import javax.crypto.spec.PBEKeySpec;
import javax.crypto.spec.PBEParameterSpec;

public interface PBE {
   int MD5 = 0;
   int SHA1 = 1;
   int RIPEMD160 = 2;
   int TIGER = 3;
   int SHA256 = 4;
   int MD2 = 5;
   int PKCS5S1 = 0;
   int PKCS5S2 = 1;
   int PKCS12 = 2;
   int OPENSSL = 3;

   public static class Util {
      private static PBEParametersGenerator makePBEGenerator(int type, int hash) {
         Object var10000;
         Object type1;
         MD2Digest hash1;
         SHA1Digest hash2;
         MD5Digest hash3;
         if (type == 0) {
            if (hash != 0) {
               if (hash != 1) {
                  if (hash != 5) {
                     throw new IllegalStateException("PKCS5 scheme 1 only supports MD2, MD5 and SHA1.");
                  }

                  var10000 = type1 = new PKCS5S1ParametersGenerator;
                  hash1 = new MD2Digest.<init>();
                  var10000.<init>(hash1);
               } else {
                  var10000 = type1 = new PKCS5S1ParametersGenerator;
                  hash2 = new SHA1Digest.<init>();
                  var10000.<init>(hash2);
               }
            } else {
               var10000 = type1 = new PKCS5S1ParametersGenerator;
               hash3 = new MD5Digest.<init>();
               var10000.<init>(hash3);
            }
         } else if (type == 1) {
            type1 = new PKCS5S2ParametersGenerator.<init>();
         } else if (type == 2) {
            switch (hash) {
               case 0:
                  var10000 = type1 = new PKCS12ParametersGenerator;
                  hash3 = new MD5Digest.<init>();
                  var10000.<init>(hash3);
                  break;
               case 1:
                  var10000 = type1 = new PKCS12ParametersGenerator;
                  hash2 = new SHA1Digest.<init>();
                  var10000.<init>(hash2);
                  break;
               case 2:
                  var10000 = type1 = new PKCS12ParametersGenerator;
                  RIPEMD160Digest hash6;
                  hash6 = new RIPEMD160Digest.<init>();
                  var10000.<init>(hash6);
                  break;
               case 3:
                  var10000 = type1 = new PKCS12ParametersGenerator;
                  TigerDigest hash5;
                  hash5 = new TigerDigest.<init>();
                  var10000.<init>(hash5);
                  break;
               case 4:
                  var10000 = type1 = new PKCS12ParametersGenerator;
                  SHA256Digest hash4;
                  hash4 = new SHA256Digest.<init>();
                  var10000.<init>(hash4);
                  break;
               case 5:
                  var10000 = type1 = new PKCS12ParametersGenerator;
                  hash1 = new MD2Digest.<init>();
                  var10000.<init>(hash1);
                  break;
               default:
                  throw new IllegalStateException("unknown digest scheme for PBE encryption.");
            }
         } else {
            type1 = new OpenSSLPBEParametersGenerator.<init>();
         }

         return (PBEParametersGenerator)type1;
      }

      static CipherParameters makePBEParameters(JCEPBEKey pbeKey, AlgorithmParameterSpec spec, String targetAlgorithm) {
         if (spec != null && spec instanceof PBEParameterSpec) {
            PBEParameterSpec spec1 = (PBEParameterSpec)spec;
            PBEParametersGenerator var3 = makePBEGenerator(pbeKey.getType(), pbeKey.getDigest());
            byte[] var4 = pbeKey.getEncoded();
            if (pbeKey.shouldTryWrongPKCS12()) {
               var4 = new byte[2];
            }

            byte[] spec2 = spec1.getSalt();
            var3.init(var4, spec2, spec1.getIterationCount());
            CipherParameters pbeKey2;
            if (pbeKey.getIvSize() != 0) {
               int pbeKey1 = pbeKey.getKeySize();
               pbeKey2 = var3.generateDerivedParameters(pbeKey1, pbeKey.getIvSize());
            } else {
               pbeKey2 = var3.generateDerivedParameters(pbeKey.getKeySize());
            }

            if (targetAlgorithm.startsWith("DES")) {
               if (pbeKey2 instanceof ParametersWithIV) {
                  DESParameters.setOddParity(((KeyParameter)((ParametersWithIV)pbeKey2).getParameters()).getKey());
               } else {
                  DESParameters.setOddParity(((KeyParameter)pbeKey2).getKey());
               }
            }

            for(int spec3 = 0; spec3 != var4.length; ++spec3) {
               var4[spec3] = 0;
            }

            return pbeKey2;
         } else {
            throw new IllegalArgumentException("Need a PBEParameter spec with a PBE key.");
         }
      }

      static CipherParameters makePBEMacParameters(JCEPBEKey pbeKey, AlgorithmParameterSpec spec) {
         if (spec != null && spec instanceof PBEParameterSpec) {
            PBEParameterSpec spec1 = (PBEParameterSpec)spec;
            PBEParametersGenerator var2 = makePBEGenerator(pbeKey.getType(), pbeKey.getDigest());
            byte[] var3 = pbeKey.getEncoded();
            if (pbeKey.shouldTryWrongPKCS12()) {
               var3 = new byte[2];
            }

            byte[] pbeKey1 = spec1.getSalt();
            var2.init(var3, pbeKey1, spec1.getIterationCount());
            CipherParameters pbeKey2 = var2.generateDerivedMacParameters(pbeKey.getKeySize());

            for(int spec2 = 0; spec2 != var3.length; ++spec2) {
               var3[spec2] = 0;
            }

            return pbeKey2;
         } else {
            throw new IllegalArgumentException("Need a PBEParameter spec with a PBE key.");
         }
      }

      static CipherParameters makePBEParameters(PBEKeySpec keySpec, int type, int hash, int keySize, int ivSize) {
         PBEParametersGenerator type1 = makePBEGenerator(type, hash);
         byte[] hash1;
         if (type == 2) {
            hash1 = PBEParametersGenerator.PKCS12PasswordToBytes(keySpec.getPassword());
         } else {
            hash1 = PBEParametersGenerator.PKCS5PasswordToBytes(keySpec.getPassword());
         }

         byte[] keySpec1 = keySpec.getSalt();
         int var5 = keySpec.getIterationCount();
         type1.init(hash1, keySpec1, var5);
         CipherParameters keySpec2;
         if (ivSize != 0) {
            keySpec2 = type1.generateDerivedParameters(keySize, ivSize);
         } else {
            keySpec2 = type1.generateDerivedParameters(keySize);
         }

         for(type = 0; type != hash1.length; ++type) {
            hash1[type] = 0;
         }

         return keySpec2;
      }

      static CipherParameters makePBEMacParameters(PBEKeySpec keySpec, int type, int hash, int keySize) {
         PBEParametersGenerator type1 = makePBEGenerator(type, hash);
         byte[] hash1;
         if (type == 2) {
            hash1 = PBEParametersGenerator.PKCS12PasswordToBytes(keySpec.getPassword());
         } else {
            hash1 = PBEParametersGenerator.PKCS5PasswordToBytes(keySpec.getPassword());
         }

         byte[] keySpec1 = keySpec.getSalt();
         type = keySpec.getIterationCount();
         type1.init(hash1, keySpec1, type);
         CipherParameters keySpec2 = type1.generateDerivedMacParameters(keySize);

         for(type = 0; type != hash1.length; ++type) {
            hash1[type] = 0;
         }

         return keySpec2;
      }
   }
}
